#' @importFrom omopgenerics cohortCount
#' @export
omopgenerics::cohortCount

#' @importFrom omopgenerics settings
#' @export
omopgenerics::settings

#' @importFrom omopgenerics attrition
#' @export
omopgenerics::attrition

#' @importFrom omopgenerics cohortCodelist
#' @export
omopgenerics::cohortCodelist

#' @importFrom omopgenerics bind
#' @export
omopgenerics::bind

#' @importFrom omopgenerics suppress
#' @export
omopgenerics::suppress

#' @importFrom omopgenerics exportSummarisedResult
#' @export
omopgenerics::exportSummarisedResult

#' @importFrom omopgenerics importSummarisedResult
#' @export
omopgenerics::importSummarisedResult

#' @importFrom omopgenerics tidy
#' @export
omopgenerics::tidy

#' @importFrom omopgenerics groupColumns
#' @export
omopgenerics::groupColumns

#' @importFrom omopgenerics strataColumns
#' @export
omopgenerics::strataColumns

#' @importFrom omopgenerics additionalColumns
#' @export
omopgenerics::additionalColumns

#' @importFrom omopgenerics settingsColumns
#' @export
omopgenerics::settingsColumns
